searchData={"items":[{"type":"module","title":"GeoSpatialite","doc":"Implements encoding and decoding for SpatiaLite geometries.\n\nSpatiaLite geometries are a slightly modified form of the well-known\nbinary (WKB) format.","ref":"GeoSpatialite.html"},{"type":"function","title":"GeoSpatialite.decode/1","doc":"","ref":"GeoSpatialite.html#decode/1"},{"type":"function","title":"GeoSpatialite.decode!/1","doc":"","ref":"GeoSpatialite.html#decode!/1"},{"type":"function","title":"GeoSpatialite.encode/2","doc":"","ref":"GeoSpatialite.html#encode/2"},{"type":"function","title":"GeoSpatialite.encode!/2","doc":"","ref":"GeoSpatialite.html#encode!/2"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [v0.1.0] - 2025-03-04","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial Release","ref":"changelog.html#added"},{"type":"extras","title":"GeoSpatialite","doc":"# GeoSpatialite\n\nImplements encoding and decoding [geo](https://github.com/felt/geo) geometries to [SpatiaLite format](https://www.gaia-gis.it/gaia-sins/BLOB-Geometry.html).\n\nGeometries currently supported:\n\n- Point\n- LineString\n- Polygon\n- MultiPolygon\n\nGeometries not yet supported:\n\n- PointZ\n- PointM\n- PointZM\n- LineStringZ\n- LineStringZM\n- PolygonZ\n- MultiPointZ\n- MultiLineString\n- MultiLineStringZ\n- MultiPoint\n- MultiPolygonZ\n- GeometryCollection\n\nThe TinyPoint encoding is also not yet supported.","ref":"readme.html"},{"type":"extras","title":"Installation - GeoSpatialite","doc":"```elixir\ndef deps do\n  [\n    {:geo_spatialite, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Spatialite - GeoSpatialite","doc":"#### macOS\n\n```sh\nbrew install spatialite-tools\n```\n\n#### Debian\n\n```sh\napt-get install libsqlite3-mod-spatialite\n```","ref":"readme.html#spatialite"},{"type":"extras","title":"Ecto - GeoSpatialite","doc":"","ref":"readme.html#ecto"},{"type":"extras","title":"Setup - GeoSpatialite","doc":"Databases must initialize SpatiaLite via a migration and call extension-specific functions for managing columns and indexing.\n\n```elixir\ndefmodule App.Repo.Migrations.InitializeSpatialite do\n  use Ecto.Migration\n\n  def change do\n    execute(\n      \"\"\"\n      SELECT InitSpatialMetaData();\n      \"\"\"\n    )\n  end\nend\n\ndefmodule App.Repo.Migrations.CreateCats do\n  use Ecto.Migration\n\n  def change do\n    create table(:cats) do\n      add :name, :string\n    end\n\n    execute(\n      \"\"\"\n      SELECT AddGeometryColumn('cats', 'geom_point', 4326, 'POINT');\n      \"\"\",\n      \"\"\"\n      SELECT DiscardGeometryColumn('cats', 'geom_point');\n      ALTER TABLE cats DROP COLUMN geom_point;\n      \"\"\"\n    )\n\n    # Indexing (optional)\n    execute(\n      \"\"\"\n      SELECT CreateSpatialIndex('cats', 'geom_point');\n      \"\"\",\n      \"\"\"\n      SELECT DisableSpatialIndex('cats', 'geom_point');\n      DROP INDEX idx_cats_geom_point;\n      \"\"\"\n    )\n  end\nend\n```","ref":"readme.html#setup"},{"type":"extras","title":"Schema - GeoSpatialite","doc":"```elixir\ndefmodule Cat do\n  use Ecto.Schema\n\n  schema \"cats\" do\n    field :name, :string\n    field :geom, GeoSpatialite.Geometry\n  end\nend\n```","ref":"readme.html#schema"},{"type":"extras","title":"Extension - GeoSpatialite","doc":"The SpatiaLite extension must be loaded via the [load_extensions](https://hexdocs.pm/exqlite/Exqlite.Connection.html#connect/1) option. Assuming a Homebrew installation on macOS, the configuration would be something like:\n\n```elixir\n# config/dev.exs\n\nconfig :app, App.Repo,\n  database: Path.expand(\"../app_dev.db\", Path.dirname(__ENV__.file)),\n  pool_size: 5,\n  stacktrace: true,\n  load_extensions: [\n    \"/opt/homebrew/lib/mod_spatialite.dylib\"\n  ],\n  show_sensitive_data_on_connection_error: true\n```\n\nAnother example could be using runtime configuration to deploy to a Debian-based Docker container:\n\n```elixir\n# config/runtime.exs\n\n  config :app, App.Repo,\n    database: database_path,\n    pool_size: String.to_integer(System.get_env(\"POOL_SIZE\") || \"5\"),\n    custom_pragmas: [{\"trusted_schema\", true}],\n    load_extensions: [\n      \"/usr/lib/x86_64-linux-gnu/mod_spatialite.so\"\n    ]\n```","ref":"readme.html#extension"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}